<?php
/**
 * Catering Services Theme Customizer
 *
 * @package Catering Services
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function catering_services_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'catering_services_custom_controls' );

function catering_services_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.logo .site-title a',
	 	'render_callback' => 'catering_services_Customize_partial_blogname',
	));

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => 'p.site-description',
		'render_callback' => 'catering_services_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'catering_services_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'Homepage Settings', 'catering-services' ),
		'priority' => 10,
	));

  //Menus Settings
  $wp_customize->add_section( 'catering_services_menu_section_setting' , array(
  	'title' => __( 'Menus Settings', 'catering-services' ),
    'panel' => 'catering_services_panel_id'
  ) );

  $wp_customize->add_setting('catering_services_navigation_menu_font_size',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('catering_services_navigation_menu_font_size',array(
    'label' => __('Menus Font Size','catering-services'),
    'description' => __('Enter a value in pixels. Example:20px','catering-services'),
    'input_attrs' => array(
    'placeholder' => __( '10px', 'catering-services' ),
        ),
    'section'=> 'catering_services_menu_section_setting',
    'type'=> 'text'
  ));

  $wp_customize->add_setting('catering_services_navigation_menu_font_weight',array(
    'default' => 600,
    'transport' => 'refresh',
    'sanitize_callback' => 'catering_services_sanitize_choices'
  ));
  $wp_customize->add_control('catering_services_navigation_menu_font_weight',array(
    'type' => 'select',
    'label' => __('Menus Font Weight','catering-services'),
    'section' => 'catering_services_menu_section_setting',
    'choices' => array(
      '100' => __('100','catering-services'),
        '200' => __('200','catering-services'),
        '300' => __('300','catering-services'),
        '400' => __('400','catering-services'),
        '500' => __('500','catering-services'),
        '600' => __('600','catering-services'),
        '700' => __('700','catering-services'),
        '800' => __('800','catering-services'),
        '900' => __('900','catering-services'),
        ),
  ) );

  // text trasform
  $wp_customize->add_setting('catering_services_menu_text_transform',array(
    'default'=> 'Capitalize',
    'sanitize_callback' => 'catering_services_sanitize_choices'
  ));
  $wp_customize->add_control('catering_services_menu_text_transform',array(
    'type' => 'radio',
    'label' => __('Menus Text Transform','catering-services'),
    'choices' => array(
            'Uppercase' => __('Uppercase','catering-services'),
            'Capitalize' => __('Capitalize','catering-services'),
            'Lowercase' => __('Lowercase','catering-services'),
        ),
    'section'=> 'catering_services_menu_section_setting',
  ));

  $wp_customize->add_setting('catering_services_menus_item_style',array(
    'default' => '',
    'transport' => 'refresh',
    'sanitize_callback' => 'catering_services_sanitize_choices'
  ));
  $wp_customize->add_control('catering_services_menus_item_style',array(
    'type' => 'select',
    'section' => 'catering_services_menu_section_setting',
    'label' => __('Menu Item Hover Style','catering-services'),
    'choices' => array(
        'None' => __('None','catering-services'),
        'Zoom In' => __('Zoom In','catering-services'),
        ),
  ) );

  $wp_customize->add_setting('catering_services_header_menus_color', array(
    'default'           => '',
    'sanitize_callback' => 'sanitize_hex_color',
  ));
  $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'catering_services_header_menus_color', array(
    'label'    => __('Menus Color', 'catering-services'),
    'section'  => 'catering_services_menu_section_setting',
  )));

  $wp_customize->add_setting('catering_services_header_menus_hover_color', array(
    'default'           => '',
    'sanitize_callback' => 'sanitize_hex_color',
  ));
  $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'catering_services_header_menus_hover_color', array(
    'label'    => __('Menus Hover Color', 'catering-services'),
    'section'  => 'catering_services_menu_section_setting',
  )));

  $wp_customize->add_setting('catering_services_header_submenus_color', array(
    'default'           => '',
    'sanitize_callback' => 'sanitize_hex_color',
  ));
  $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'catering_services_header_submenus_color', array(
    'label'    => __('Sub Menus Color', 'catering-services'),
    'section'  => 'catering_services_menu_section_setting',
  )));

  $wp_customize->add_setting('catering_services_header_submenus_hover_color', array(
    'default'           => '',
    'sanitize_callback' => 'sanitize_hex_color',
  ));
  $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'catering_services_header_submenus_hover_color', array(
    'label'    => __('Sub Menus Hover Color', 'catering-services'),
    'section'  => 'catering_services_menu_section_setting',
  )));

	//Slider
	$wp_customize->add_section( 'catering_services_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'catering-services' ),
		'description' => __('Free theme has 3 slides options, For unlimited slides and more options </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/catering-wordpress-theme/">GO PRO</a>','catering-services'),
		'panel' => 'catering_services_panel_id'
	) );

	$wp_customize->add_setting( 'catering_services_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'catering_services_switch_sanitization'
  ));
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_slider_hide_show',array(
    'label' => esc_html__( 'Show / Hide Slider','catering-services' ),
    'section' => 'catering_services_slidersettings'
  )));

  $wp_customize->add_setting('catering_services_slider_type',array(
        'default' => 'Default slider',
        'sanitize_callback' => 'catering_services_sanitize_choices'
	) );
	$wp_customize->add_control('catering_services_slider_type', array(
        'type' => 'select',
        'label' => __('Slider Type','catering-services'),
        'section' => 'catering_services_slidersettings',
        'choices' => array(
            'Default slider' => __('Default slider','catering-services'),
            'Advance slider' => __('Advance slider','catering-services'),
        ),
	));

	$wp_customize->add_setting('catering_services_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','catering-services'),
		'section'=> 'catering_services_slidersettings',
		'type'=> 'text',
		'active_callback' => 'catering_services_advance_slider'
	));


   //Selective Refresh
  $wp_customize->selective_refresh->add_partial('catering_services_slider_hide_show',array(
	'selector'        => '.slider-btn a',
	'render_callback' => 'catering_services_customize_partial_catering_services_slider_hide_show',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'catering_services_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'catering_services_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'catering_services_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'catering-services' ),
			'description' => __('Slider image size (1400 x 550)','catering-services'),
			'section'  => 'catering_services_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'catering_services_default_slider'
		) );
	}

	//content layout
	$wp_customize->add_setting('catering_services_slider_content_option',array(
        'default' => 'Left',
        'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control(new catering_services_Image_Radio_Control($wp_customize, 'catering_services_slider_content_option', array(
        'type' => 'select',
        'label' => esc_html__('Slider Content Layouts','catering-services'),
        'section' => 'catering_services_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
  ),'active_callback' => 'catering_services_default_slider'
  )));

   //Slider content padding
    $wp_customize->add_setting('catering_services_slider_content_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_slider_content_padding_top_bottom',array(
		'label'	=> __('Slider Content Padding Top Bottom','catering-services'),
		'description'	=> __('Enter a value in %. Example:20%','catering-services'),
		'input_attrs' => array(
    'placeholder' => __( '50%', 'catering-services' ),
        ),
		'section'=> 'catering_services_slidersettings',
		'type'=> 'text',
		'active_callback' => 'catering_services_default_slider'
	));

	$wp_customize->add_setting('catering_services_slider_content_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_slider_content_padding_left_right',array(
		'label'	=> __('Slider Content Padding Left Right','catering-services'),
		'description'	=> __('Enter a value in %. Example:20%','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'catering-services' ),
        ),
		'section'=> 'catering_services_slidersettings',
		'type'=> 'text',
		'active_callback' => 'catering_services_default_slider'
	));

    //Slider excerpt
	$wp_customize->add_setting( 'catering_services_slider_excerpt_number', array(
		'default'              => 10,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'catering_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'catering_services_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','catering-services' ),
		'section'     => 'catering_services_slidersettings',
		'type'        => 'range',
		'settings'    => 'catering_services_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),'active_callback' => 'catering_services_default_slider'
	) );

	$wp_customize->add_setting( 'catering_services_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'catering_services_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','catering-services'),
		'section' => 'catering_services_slidersettings',
		'type'  => 'text',
		'active_callback' => 'catering_services_default_slider'
	) );

	//Slider height
	$wp_customize->add_setting('catering_services_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_slider_height',array(
		'label'	=> __('Slider Height','catering-services'),
		'description'	=> __('Specify the slider height (px).','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'catering-services' ),
        ),
		'section'=> 'catering_services_slidersettings',
		'type'=> 'text',
		'active_callback' => 'catering_services_default_slider'
	));

	//Opacity
	$wp_customize->add_setting('catering_services_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control( 'catering_services_slider_opacity_color', array(
		'label'       => esc_html__( 'Slider Image Opacity','catering-services' ),
		'section'     => 'catering_services_slidersettings',
		'type'        => 'select',
		'settings'    => 'catering_services_slider_opacity_color',
		'choices' => array(
			'0' =>  esc_attr('0','catering-services'),
			'0.1' =>  esc_attr('0.1','catering-services'),
			'0.2' =>  esc_attr('0.2','catering-services'),
			'0.3' =>  esc_attr('0.3','catering-services'),
			'0.4' =>  esc_attr('0.4','catering-services'),
			'0.5' =>  esc_attr('0.5','catering-services'),
			'0.6' =>  esc_attr('0.6','catering-services'),
			'0.7' =>  esc_attr('0.7','catering-services'),
			'0.8' =>  esc_attr('0.8','catering-services'),
			'0.9' =>  esc_attr('0.9','catering-services')
	),'active_callback' => 'catering_services_default_slider'
	));

	$wp_customize->add_setting( 'catering_services_slider_image_overlay',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'catering_services_switch_sanitization'
  ));
  $wp_customize->add_control( new catering_services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_slider_image_overlay',array(
    	'label' => esc_html__( 'Slider Image Overlay','catering-services' ),
    	'section' => 'catering_services_slidersettings',
    	'active_callback' => 'catering_services_default_slider'
  )));

  $wp_customize->add_setting('catering_services_slider_image_overlay_color', array(
			'default'           => '#000',
			'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'catering_services_slider_image_overlay_color', array(
		'label'    => __('Slider Image Overlay Color', 'catering-services'),
		'section'  => 'catering_services_slidersettings',
		'active_callback' => 'catering_services_default_slider'
	)));

	//About Section
	$wp_customize->add_section('catering_services_about_section', array(
		'title'       => __('About Section', 'catering-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','catering-services'),
		'priority'    => null,
		'panel'       => 'catering_services_panel_id',
	));

	$wp_customize->add_setting('catering_services_about_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_about_text',array(
		'description' => __('<p>1. More options for about section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for about section.</p>','catering-services'),
		'section'=> 'catering_services_about_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('catering_services_about_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_about_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=catering_services_guide') ." '>More Info</a>",
		'section'=> 'catering_services_about_section',
		'type'=> 'hidden'
	));

	//Services Section
	$wp_customize->add_section('catering_services_services_section', array(
		'title'       => __('Services Section', 'catering-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','catering-services'),
		'priority'    => null,
		'panel'       => 'catering_services_panel_id',
	));

	$wp_customize->add_setting('catering_services_services_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_services_text',array(
		'description' => __('<p>1. More options for services section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for services section.</p>','catering-services'),
		'section'=> 'catering_services_services_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('catering_services_services_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_services_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=catering_services_guide') ." '>More Info</a>",
		'section'=> 'catering_services_services_section',
		'type'=> 'hidden'
	));

	//Popular Dishes Products Section
	$wp_customize->add_section('catering_services_popular_dishes_products_section',array(
		'title'	=> __('Best Seller Products Section','catering-services'),
		'description' => __('For more options of product section</br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/catering-wordpress-theme/">GO PRO</a>','catering-services'),
		'panel' => 'catering_services_panel_id',
	));

	$wp_customize->add_setting( 'catering_services_product_hide_show',array(
	    'default' => 0,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'catering_services_switch_sanitization'
	));
	$wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_product_hide_show',array(
		'label' => esc_html__( 'Show / Hide Product Section','catering-services' ),
		'section' => 'catering_services_popular_dishes_products_section'
	)));

	$wp_customize->add_setting( 'catering_services_popular_dishes_banner_page' , array(
		'default'           => '',
		'sanitize_callback' => 'catering_services_sanitize_dropdown_pages'
	));
	$wp_customize->add_control( 'catering_services_popular_dishes_banner_page' , array(
		'label'    => __( 'Select Banner Page', 'catering-services' ),
		'section'  => 'catering_services_popular_dishes_products_section',
		'type'     => 'dropdown-pages'
	) );

	$args = array(
		'type'         => 'product',
		'child_of'     => 0,
		'parent'       => '',
		'orderby'      => 'term_group',
		'order'        => 'ASC',
		'hide_empty'   => false,
		'hierarchical' => 1,
		'number'       => '',
		'taxonomy'     => 'product_cat',
		'pad_counts'   => false
	);
 	$categories = get_categories( $args );
	$cat_posts = array();
	$i = 0;
	$cat_posts[]='Select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('catering_services_popular_dishes_page',array(
		'default'	=> 'select',
		'sanitize_callback' => 'catering_services_sanitize_choices',
	));
	$wp_customize->add_control('catering_services_popular_dishes_page',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display Products','catering-services'),
		'section' => 'catering_services_popular_dishes_products_section',
	));

	//Records Section
	$wp_customize->add_section('catering_services_records_section', array(
		'title'       => __('Records Section', 'catering-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','catering-services'),
		'priority'    => null,
		'panel'       => 'catering_services_panel_id',
	));

	$wp_customize->add_setting('catering_services_records_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_records_text',array(
		'description' => __('<p>1. More options for records section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for records section.</p>','catering-services'),
		'section'=> 'catering_services_records_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('catering_services_records_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_records_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=catering_services_guide') ." '>More Info</a>",
		'section'=> 'catering_services_records_section',
		'type'=> 'hidden'
	));

	//Menu Section
	$wp_customize->add_section('catering_services_menu_section', array(
		'title'       => __('Our Menu Section', 'catering-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','catering-services'),
		'priority'    => null,
		'panel'       => 'catering_services_panel_id',
	));

	$wp_customize->add_setting('catering_services_menu_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_menu_text',array(
		'description' => __('<p>1. More options for our menu section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our menu section.</p>','catering-services'),
		'section'=> 'catering_services_menu_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('catering_services_menu_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_menu_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=catering_services_guide') ." '>More Info</a>",
		'section'=> 'catering_services_menu_section',
		'type'=> 'hidden'
	));

	//Category Section
	$wp_customize->add_section('catering_services_Category_section', array(
		'title'       => __('Category Section', 'catering-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','catering-services'),
		'priority'    => null,
		'panel'       => 'catering_services_panel_id',
	));

	$wp_customize->add_setting('catering_services_Category_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_Category_text',array(
		'description' => __('<p>1. More options for Category section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Category section.</p>','catering-services'),
		'section'=> 'catering_services_Category_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('catering_services_Category_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_Category_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=catering_services_guide') ." '>More Info</a>",
		'section'=> 'catering_services_Category_section',
		'type'=> 'hidden'
	));

	//Team Section
	$wp_customize->add_section('catering_services_team_section', array(
		'title'       => __('Team Section', 'catering-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','catering-services'),
		'priority'    => null,
		'panel'       => 'catering_services_panel_id',
	));

	$wp_customize->add_setting('catering_services_team_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_team_text',array(
		'description' => __('<p>1. More options for team section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for team section.</p>','catering-services'),
		'section'=> 'catering_services_team_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('catering_services_team_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_team_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=catering_services_guide') ." '>More Info</a>",
		'section'=> 'catering_services_team_section',
		'type'=> 'hidden'
	));

	//Testimonial Section
	$wp_customize->add_section('catering_services_testimonial_section', array(
		'title'       => __('Testimonial Section', 'catering-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','catering-services'),
		'priority'    => null,
		'panel'       => 'catering_services_panel_id',
	));

	$wp_customize->add_setting('catering_services_testimonial_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_testimonial_text',array(
		'description' => __('<p>1. More options for testimonial section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for testimonial section.</p>','catering-services'),
		'section'=> 'catering_services_testimonial_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('catering_services_testimonial_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_testimonial_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=catering_services_guide') ." '>More Info</a>",
		'section'=> 'catering_services_testimonial_section',
		'type'=> 'hidden'
	));

	//Our Blog Section
	$wp_customize->add_section('catering_services_our_blog_section', array(
		'title'       => __('Our Blog Section', 'catering-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','catering-services'),
		'priority'    => null,
		'panel'       => 'catering_services_panel_id',
	));

	$wp_customize->add_setting('catering_services_our_blog_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_our_blog_text',array(
		'description' => __('<p>1. More options for our blog section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our blog section.</p>','catering-services'),
		'section'=> 'catering_services_our_blog_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('catering_services_our_blog_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_our_blog_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=catering_services_guide') ." '>More Info</a>",
		'section'=> 'catering_services_our_blog_section',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('catering_services_footer',array(
		'title'	=> esc_html__('Footer Settings','catering-services'),
		'description' => __('For more options of Footer section</br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/catering-wordpress-theme/">GO PRO</a>','catering-services'),
		'panel' => 'catering_services_panel_id',
	));

	$wp_customize->add_setting( 'catering_services_footer_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'catering_services_switch_sanitization'
  ));
  $wp_customize->add_control( new catering_services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_footer_hide_show',array(
    'label' => esc_html__( 'Show / Hide Footer','catering-services' ),
    'section' => 'catering_services_footer'
  )));

	$wp_customize->add_setting('catering_services_footer_background_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'catering_services_footer_background_color', array(
		'label'    => __('Footer Background Color', 'catering-services'),
		'section'  => 'catering_services_footer',
	)));

	$wp_customize->add_setting('catering_services_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'catering_services_footer_background_image',array(
        'label' => __('Footer Background Image','catering-services'),
        'section' => 'catering_services_footer'
	)));

	$wp_customize->add_setting('catering_services_footer_img_position',array(
	  'default' => 'center center',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control('catering_services_footer_img_position',array(
		'type' => 'select',
		'label' => __('Footer Image Position','catering-services'),
		'section' => 'catering_services_footer',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'catering-services' ),
			'center top'   => esc_html__( 'Top', 'catering-services' ),
			'right top'   => esc_html__( 'Top Right', 'catering-services' ),
			'left center'   => esc_html__( 'Left', 'catering-services' ),
			'center center'   => esc_html__( 'Center', 'catering-services' ),
			'right center'   => esc_html__( 'Right', 'catering-services' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'catering-services' ),
			'center bottom'   => esc_html__( 'Bottom', 'catering-services' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'catering-services' ),
		),
	)); 

	// Footer
	$wp_customize->add_setting('catering_services_img_footer',array(
		'default'=> 'scroll',
		'sanitize_callback'	=> 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control('catering_services_img_footer',array(
		'type' => 'select',
		'label'	=> __('Footer Background Attatchment','catering-services'),
		'choices' => array(
      'fixed' => __('fixed','catering-services'),
      'scroll' => __('scroll','catering-services'),
      ),
		'section'=> 'catering_services_footer',
	));

	$wp_customize->add_setting('catering_services_footer_widgets_heading',array(
    'default' => 'Left',
    'transport' => 'refresh',
    'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control('catering_services_footer_widgets_heading',array(
    'type' => 'select',
    'label' => __('Footer Widget Heading','catering-services'),
    'section' => 'catering_services_footer',
    'choices' => array(
    	'Left' => __('Left','catering-services'),
        'Center' => __('Center','catering-services'),
        'Right' => __('Right','catering-services')
      ),
	) );

	$wp_customize->add_setting('catering_services_footer_widgets_content',array(
    'default' => 'Left',
    'transport' => 'refresh',
    'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control('catering_services_footer_widgets_content',array(
    'type' => 'select',
    'label' => __('Footer Widget Content','catering-services'),
    'section' => 'catering_services_footer',
    'choices' => array(
    	'Left' => __('Left','catering-services'),
        'Center' => __('Center','catering-services'),
        'Right' => __('Right','catering-services')
        ),
	) );

	// footer padding
	$wp_customize->add_setting('catering_services_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'catering-services' ),
    ),
		'section'=> 'catering_services_footer',
		'type'=> 'text'
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('catering_services_footer_text', array(
		'selector' => '.copyright p',
		'render_callback' => 'catering_services_Customize_partial_catering_services_footer_text',
	));

	$wp_customize->add_setting( 'catering_services_copyright_hide_show',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'catering_services_switch_sanitization'
  ));
  $wp_customize->add_control( new catering_services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_copyright_hide_show',array(
    'label' => esc_html__( 'Show / Hide Copyright','catering-services' ),
    'section' => 'catering_services_footer'
  )));

	$wp_customize->add_setting('catering_services_copyright_background_color', array(
		'default'           => '#eb353c',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'catering_services_copyright_background_color', array(
		'label'    => __('Copyright Background Color', 'catering-services'),
		'section'  => 'catering_services_footer',
	)));

	$wp_customize->add_setting('catering_services_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_footer_text',array(
		'label'	=> esc_html__('Copyright Text','catering-services'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2021, .....', 'catering-services' ),
        ),
		'section'=> 'catering_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_copyright_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_copyright_font_size',array(
		'label'	=> __('Copyright Font Size','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'catering-services' ),
        ),
		'section'=> 'catering_services_footer',
		'type'=> 'text'
	));

   //Selective Refresh
	$wp_customize->selective_refresh->add_partial('catering_services_scroll_to_top_icon', array(
		'selector' => '.scrollup i',
		'render_callback' => 'catering_services_Customize_partial_catering_services_scroll_to_top_icon',
	));

	$wp_customize->add_setting('catering_services_copyright_alingment',array(
    'default' => 'center',
    'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control(new Catering_Services_Image_Radio_Control($wp_customize, 'catering_services_copyright_alingment', array(
    'type' => 'select',
    'label' => esc_html__('Copyright Alignment','catering-services'),
    'section' => 'catering_services_footer',
    'settings' => 'catering_services_copyright_alingment',
    'choices' => array(
        'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
        'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
        'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
  ))));

  $wp_customize->add_setting( 'catering_services_hide_show_scroll',array(
  	'default' => 1,
  	'transport' => 'refresh',
  	'sanitize_callback' => 'catering_services_switch_sanitization'
  ));
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_hide_show_scroll',array(
    	'label' => esc_html__( 'Show / Hide Scroll to Top','catering-services' ),
    	'section' => 'catering_services_footer'
  )));

  //Selective Refresh
	$wp_customize->selective_refresh->add_partial('catering_services_scroll_to_top_icon', array(
		'selector' => '.scrollup i',
		'render_callback' => 'catering_services_customize_partial_catering_services_scroll_to_top_icon',
	));

  $wp_customize->add_setting('catering_services_scroll_to_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Catering_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_scroll_to_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_footer',
		'setting'	=> 'catering_services_scroll_to_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('catering_services_scroll_to_top_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_scroll_to_top_font_size',array(
		'label'	=> __('Icon Font Size','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'catering-services' ),
        ),
		'section'=> 'catering_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_scroll_to_top_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_scroll_to_top_padding',array(
		'label'	=> __('Icon Top Bottom Padding','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'catering-services' ),
        ),
		'section'=> 'catering_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_scroll_to_top_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_scroll_to_top_width',array(
		'label'	=> __('Icon Width','catering-services'),
		'description'	=> __('Enter a value in pixels Example:20px','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'catering-services' ),
        ),
		'section'=> 'catering_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_scroll_to_top_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_scroll_to_top_height',array(
		'label'	=> __('Icon Height','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'catering-services' ),
        ),
		'section'=> 'catering_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'catering_services_scroll_to_top_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'catering_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'catering_services_scroll_to_top_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','catering-services' ),
		'section'     => 'catering_services_footer',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_panel( 'catering_services_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'catering-services' ),
		'panel' => 'catering_services_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'catering_services_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'catering-services' ),
		'panel' => 'catering_services_blog_post_parent_panel',
	));

	//Blog layout
	$wp_customize->add_setting('catering_services_blog_layout_option',array(
	  'default' => 'Default',
	  'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control(new catering_services_Image_Radio_Control($wp_customize, 'catering_services_blog_layout_option', array(
	  'type' => 'select',
	  'label' => esc_html__('Blog Post Layouts','catering-services'),
	  'section' => 'catering_services_post_settings',
	  'choices' => array(
	      'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
	      'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
	      'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
	))));

	$wp_customize->add_setting('catering_services_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control('catering_services_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','catering-services'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','catering-services'),
        'section' => 'catering_services_post_settings',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','catering-services'),
            'Right Sidebar' => esc_html__('Right Sidebar','catering-services'),
            'One Column' => esc_html__('One Column','catering-services'),
            'Grid Layout' => esc_html__('Grid Layout','catering-services')
        ),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('catering_services_toggle_postdate', array(
		'selector' => '.post-main-box h2 a',
		'render_callback' => 'catering_services_Customize_partial_catering_services_toggle_postdate',
	));

	$wp_customize->add_setting('catering_services_toggle_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new catering_services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_toggle_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_post_settings',
		'setting'	=> 'catering_services_toggle_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'catering_services_toggle_postdate',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_toggle_postdate',array(
    'label' => esc_html__( 'Post Date','catering-services' ),
    'section' => 'catering_services_post_settings'
  )));

	$wp_customize->add_setting('catering_services_toggle_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new catering_services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_toggle_author_icon',array(
		'label'	=> __('Add Author Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_post_settings',
		'setting'	=> 'catering_services_toggle_author_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'catering_services_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_toggle_author',array(
		'label' => esc_html__( 'Author','catering-services' ),
		'section' => 'catering_services_post_settings'
  )));

  $wp_customize->add_setting('catering_services_toggle_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new catering_services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_toggle_comments_icon',array(
		'label'	=> __('Add Comments Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_post_settings',
		'setting'	=> 'catering_services_toggle_comments_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'catering_services_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_toggle_comments',array(
		'label' => esc_html__( 'Comments','catering-services' ),
		'section' => 'catering_services_post_settings'
  )));

  $wp_customize->add_setting('catering_services_toggle_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new catering_services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_toggle_time_icon',array(
		'label'	=> __('Add Time Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_post_settings',
		'setting'	=> 'catering_services_toggle_time_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'catering_services_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_toggle_time',array(
		'label' => esc_html__( 'Time','catering-services' ),
		'section' => 'catering_services_post_settings'
  )));

  $wp_customize->add_setting( 'catering_services_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
	));
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','catering-services' ),
		'section' => 'catering_services_post_settings'
  )));

     //Featured Image
	$wp_customize->add_setting( 'catering_services_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'catering_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'catering_services_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','catering-services' ),
		'section'     => 'catering_services_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'catering_services_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'catering_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'catering_services_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','catering-services' ),
		'section'     => 'catering_services_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Featured Image
	$wp_customize->add_setting('catering_services_blog_post_featured_image_dimension',array(
       'default' => 'default',
       'sanitize_callback'	=> 'catering_services_sanitize_choices'
	));
  	$wp_customize->add_control('catering_services_blog_post_featured_image_dimension',array(
		'type' => 'select',
		'label'	=> __('Blog Post Featured Image Dimension','catering-services'),
		'section'	=> 'catering_services_post_settings',
		'choices' => array(
		'default' => __('Default','catering-services'),
		'custom' => __('Custom Image Size','catering-services'),
      ),
  	));

	$wp_customize->add_setting('catering_services_blog_post_featured_image_custom_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
		));
	$wp_customize->add_control('catering_services_blog_post_featured_image_custom_width',array(
		'label'	=> __('Featured Image Custom Width','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'catering-services' ),),
		'section'=> 'catering_services_post_settings',
		'type'=> 'text',
		'active_callback' => 'catering_services_blog_post_featured_image_dimension'
		));

	$wp_customize->add_setting('catering_services_blog_post_featured_image_custom_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_blog_post_featured_image_custom_height',array(
		'label'	=> __('Featured Image Custom Height','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'catering-services' ),),
		'section'=> 'catering_services_post_settings',
		'type'=> 'text',
		'active_callback' => 'catering_services_blog_post_featured_image_dimension'
	));

  $wp_customize->add_setting( 'catering_services_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
	));
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_toggle_tags', array(
		'label' => esc_html__( 'Tags','catering-services' ),
		'section' => 'catering_services_post_settings'
  )));

  $wp_customize->add_setting( 'catering_services_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'catering_services_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'catering_services_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','catering-services' ),
		'section'     => 'catering_services_post_settings',
		'type'        => 'range',
		'settings'    => 'catering_services_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('catering_services_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','catering-services'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','catering-services'),
		'section'=> 'catering_services_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('catering_services_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control('catering_services_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','catering-services'),
        'section' => 'catering_services_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','catering-services'),
            'Excerpt' => esc_html__('Excerpt','catering-services'),
            'No Content' => esc_html__('No Content','catering-services')
        ),
	) );

  $wp_customize->add_setting('catering_services_blog_page_posts_settings',array(
    'default' => 'Into Blocks',
    'transport' => 'refresh',
    'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control('catering_services_blog_page_posts_settings',array(
    'type' => 'select',
    'label' => __('Display Blog Page posts','catering-services'),
    'section' => 'catering_services_post_settings',
    'choices' => array(
    		'Into Blocks' => __('Into Blocks','catering-services'),
        'Without Blocks' => __('Without Blocks','catering-services')
        ),
	) );

  // Button Settings
	$wp_customize->add_section( 'catering_services_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'catering-services' ),
		'panel' => 'catering_services_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('catering_services_button_text', array(
		'selector' => '.post-main-box .more-btn a',
		'render_callback' => 'catering_services_Customize_partial_catering_services_button_text',
	));

    $wp_customize->add_setting('catering_services_button_text',array(
		'default'=> esc_html__('Read More','catering-services'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_button_text',array(
		'label'	=> esc_html__('Add Button Text','catering-services'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'catering-services' ),
        ),
		'section'=> 'catering_services_button_settings',
		'type'=> 'text'
	));

	// font size button
	$wp_customize->add_setting('catering_services_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_button_font_size',array(
		'label'	=> __('Button Font Size','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'catering-services' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'catering_services_button_settings',
	));

	$wp_customize->add_setting( 'catering_services_button_border_radius', array(
		'default'              => 5,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'catering_services_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'catering_services_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','catering-services' ),
		'section'     => 'catering_services_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('catering_services_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_button_padding_top_bottom',array(
		'label'	=> esc_html__('Padding Top Bottom','catering-services'),
		'description' => esc_html__('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '10px', 'catering-services' ),
        ),
		'section' => 'catering_services_button_settings',
		'type' => 'text'
	));

	$wp_customize->add_setting('catering_services_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_button_padding_left_right',array(
		'label'	=> esc_html__('Padding Left Right','catering-services'),
		'description' => esc_html__('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '10px', 'catering-services' ),
        ),
		'section' => 'catering_services_button_settings',
		'type' => 'text'
	));

	$wp_customize->add_setting('catering_services_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'catering-services' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'catering_services_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('catering_services_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control('catering_services_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','catering-services'),
		'choices' => array(
            'Uppercase' => __('Uppercase','catering-services'),
            'Capitalize' => __('Capitalize','catering-services'),
            'Lowercase' => __('Lowercase','catering-services'),
        ),
		'section'=> 'catering_services_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'catering_services_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'catering-services' ),
		'panel' => 'catering_services_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('catering_services_related_post_title', array(
		'selector' => '.related-post h3',
		'render_callback' => 'catering_services_Customize_partial_catering_services_related_post_title',
	));

  $wp_customize->add_setting( 'catering_services_related_post',array(
	'default' => 1,
	'transport' => 'refresh',
	'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_related_post',array(
	'label' => esc_html__( 'Related Post','catering-services' ),
	'section' => 'catering_services_related_posts_settings'
  )));

  $wp_customize->add_setting('catering_services_related_post_title',array(
	'default'=> '',
	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','catering-services'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'catering-services' ),
        ),
		'section'=> 'catering_services_related_posts_settings',
		'type'=> 'text'
	));

 	$wp_customize->add_setting('catering_services_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'catering_services_sanitize_number_absint'
	));
	$wp_customize->add_control('catering_services_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','catering-services'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'catering-services' ),
        ),
		'section'=> 'catering_services_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'catering_services_related_posts_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'catering_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'catering_services_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','catering-services' ),
		'section'     => 'catering_services_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'catering_services_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Posts Settings
	$wp_customize->add_section( 'catering_services_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'catering-services' ),
		'panel' => 'catering_services_blog_post_parent_panel',
	));

	$wp_customize->add_setting('catering_services_single_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Catering_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_single_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_single_blog_settings',
		'setting'	=> 'catering_services_single_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'catering_services_single_postdate',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_single_postdate',array(
    'label' => esc_html__( 'Post Date','catering-services' ),
    'section' => 'catering_services_single_blog_settings'
  )));

	$wp_customize->add_setting('catering_services_single_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Catering_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_single_author_icon',array(
		'label'	=> __('Add Author Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_single_blog_settings',
		'setting'	=> 'catering_services_single_author_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'catering_services_single_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_single_author',array(
		'label' => esc_html__( 'Author','catering-services' ),
		'section' => 'catering_services_single_blog_settings'
  )));

 	$wp_customize->add_setting('catering_services_single_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Catering_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_single_comments_icon',array(
		'label'	=> __('Add Comments Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_single_blog_settings',
		'setting'	=> 'catering_services_single_comments_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'catering_services_single_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_single_comments',array(
		'label' => esc_html__( 'Comments','catering-services' ),
		'section' => 'catering_services_single_blog_settings'
  )));

 	$wp_customize->add_setting('catering_services_single_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Catering_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_single_time_icon',array(
		'label'	=> __('Add Time Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_single_blog_settings',
		'setting'	=> 'catering_services_single_time_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'catering_services_single_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_single_time',array(
		'label' => esc_html__( 'Time','catering-services' ),
		'section' => 'catering_services_single_blog_settings'
  )));

	$wp_customize->add_setting( 'catering_services_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
    ) );
	$wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_single_post_breadcrumb',array(
		'label' => esc_html__( 'Single Post Breadcrumb','catering-services' ),
		'section' => 'catering_services_single_blog_settings'
	)));

  // Single Posts Category
 	$wp_customize->add_setting( 'catering_services_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
    ) );
  	$wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_single_post_category',array(
		'label' => esc_html__( 'Single Post Category','catering-services' ),
		'section' => 'catering_services_single_blog_settings'
   	)));

	$wp_customize->add_setting( 'catering_services_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
	));
    $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_toggle_tags', array(
		'label' => esc_html__( 'Tags','catering-services' ),
		'section' => 'catering_services_single_blog_settings'
    )));

	$wp_customize->add_setting( 'catering_services_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
	));
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_single_blog_post_navigation_show_hide', array(
		'label' => esc_html__( 'Post Navigation','catering-services' ),
		'section' => 'catering_services_single_blog_settings'
  )));

	$wp_customize->add_setting('catering_services_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','catering-services'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','catering-services'),
		'section'=> 'catering_services_single_blog_settings',
		'type'=> 'text'
	));

  $wp_customize->add_setting('catering_services_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','catering-services'),
		'description'	=> __('Enter a value in %. Example:50%','catering-services'),
		'input_attrs' => array(
    'placeholder' => __( '100%', 'catering-services' ),
        ),
		'section'=> 'catering_services_single_blog_settings',
		'type'=> 'text'
	));

	//navigation text
	$wp_customize->add_setting('catering_services_single_blog_prev_navigation_text',array(
		'default'=> 'PREVIOUS',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( 'PREVIOUS', 'catering-services' ),
        ),
		'section'=> 'catering_services_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_single_blog_next_navigation_text',array(
		'default'=> 'NEXT',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'catering-services' ),
        ),
		'section'=> 'catering_services_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_single_blog_comment_title',array(
		'default'=> 'Leave a Reply',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('catering_services_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','catering-services'),
		'input_attrs' => array(
        'placeholder' => __( 'Leave a Reply', 'catering-services' ),
    	),
		'section'=> 'catering_services_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_single_blog_comment_button_text',array(
		'default'=> 'Post Comment',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('catering_services_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'catering-services' ),
        ),
		'section'=> 'catering_services_single_blog_settings',
		'type'=> 'text'
	));

 	// Grid layout setting
	$wp_customize->add_section( 'catering_services_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'catering-services' ),
		'panel' => 'catering_services_blog_post_parent_panel',
	));

	$wp_customize->add_setting('catering_services_grid_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new catering_services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_grid_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_grid_layout_settings',
		'setting'	=> 'catering_services_grid_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'catering_services_grid_postdate',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'catering_services_switch_sanitization'
    ) );
  $wp_customize->add_control( new catering_services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_grid_postdate',array(
      'label' => esc_html__( 'Post Date','catering-services' ),
      'section' => 'catering_services_grid_layout_settings'
   )));

	$wp_customize->add_setting('catering_services_grid_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new catering_services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_grid_author_icon',array(
		'label'	=> __('Add Author Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_grid_layout_settings',
		'setting'	=> 'catering_services_grid_author_icon',
		'type'		=> 'icon'
	))); 

  $wp_customize->add_setting( 'catering_services_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
    ) );
  $wp_customize->add_control( new catering_services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_grid_author',array(
		'label' => esc_html__( 'Author','catering-services' ),
		'section' => 'catering_services_grid_layout_settings'
  )));

	$wp_customize->add_setting('catering_services_grid_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new catering_services_Fontawesome_Icon_Chooser(
        $wp_customize,'catering_services_grid_comments_icon',array(
		'label'	=> __('Add Comments Icon','catering-services'),
		'transport' => 'refresh',
		'section'	=> 'catering_services_grid_layout_settings',
		'setting'	=> 'catering_services_grid_comments_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'catering_services_grid_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new catering_services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_grid_comments',array(
		'label' => esc_html__( 'Comments','catering-services' ),
		'section' => 'catering_services_grid_layout_settings'
  )));

	//Other Settings
	$wp_customize->add_panel( 'catering_services_other_parent_panel', array(
		'title' => esc_html__( 'Other Settings', 'catering-services' ),
		'panel' => 'catering_services_panel_id',
		'priority' => 20,
	));

	// Layout
	$wp_customize->add_section( 'catering_services_left_right', array(
    	'title' => esc_html__('General Settings', 'catering-services'),
		'panel' => 'catering_services_other_parent_panel'
	) );

 	// Header Background color
	$wp_customize->add_setting('catering_services_header_background_color', array(
		'default'           => '#eb353c',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'catering_services_header_background_color', array(
		'label'    => __('Header Background Color', 'catering-services'),
		'section'  => 'catering_services_left_right',
	)));

	$wp_customize->add_setting( 'catering_services_search_hide_show',
       array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'catering_services_switch_sanitization'
  ));
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_search_hide_show',
     array(
    'label' => esc_html__( 'Show / Hide Search','catering-services' ),
    'section' => 'catering_services_left_right'
  )));

	$wp_customize->add_setting('catering_services_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control(new Catering_Services_Image_Radio_Control($wp_customize, 'catering_services_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','catering-services'),
        'description' => esc_html__('Here you can change the width layout of Website.','catering-services'),
        'section' => 'catering_services_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('catering_services_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control('catering_services_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','catering-services'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','catering-services'),
        'section' => 'catering_services_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','catering-services'),
            'Right_Sidebar' => esc_html__('Right Sidebar','catering-services'),
            'One_Column' => esc_html__('One Column','catering-services')
        ),
	) );

  $wp_customize->add_setting( 'catering_services_single_page_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new catering_services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_single_page_breadcrumb',array(
		'label' => esc_html__( 'Single Page Breadcrumb','catering-services' ),
		'section' => 'catering_services_left_right'
  )));

  // Pre-Loader
	$wp_customize->add_setting( 'catering_services_loader_enable',array(
    'default' => 0,
    'transport' => 'refresh',
    'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_loader_enable',array(
      'label' => esc_html__( 'Pre-Loader','catering-services' ),
      'section' => 'catering_services_left_right'
  )));

	$wp_customize->add_setting('catering_services_preloader_bg_color', array(
		'default'           => '#eb353c',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'catering_services_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'catering-services'),
		'section'  => 'catering_services_left_right',
	)));

	$wp_customize->add_setting('catering_services_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'catering_services_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'catering-services'),
		'section'  => 'catering_services_left_right',
	)));

	$wp_customize->add_setting('catering_services_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'catering_services_preloader_bg_img',array(
        'label' => __('Preloader Background Image','catering-services'),
        'section' => 'catering_services_left_right'
	)));

    //404 Page Setting
	$wp_customize->add_section('catering_services_404_page',array(
		'title'	=> __('404 Page Settings','catering-services'),
		'panel' => 'catering_services_other_parent_panel',
	));

	$wp_customize->add_setting('catering_services_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('catering_services_404_page_title',array(
		'label'	=> __('Add Title','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'catering-services' ),
        ),
		'section'=> 'catering_services_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('catering_services_404_page_content',array(
		'label'	=> __('Add Text','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'catering-services' ),
        ),
		'section'=> 'catering_services_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_404_page_button_text',array(
		'label'	=> __('Add Button Text','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( 'GO BACK', 'catering-services' ),
        ),
		'section'=> 'catering_services_404_page',
		'type'=> 'text'
	));

	//No Result Page Setting
	$wp_customize->add_section('catering_services_no_results_page',array(
		'title'	=> __('No Results Page Settings','catering-services'),
		'panel' => 'catering_services_other_parent_panel',
	));

	$wp_customize->add_setting('catering_services_no_results_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('catering_services_no_results_page_title',array(
		'label'	=> __('Add Title','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( 'Nothing Found', 'catering-services' ),
        ),
		'section'=> 'catering_services_no_results_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_no_results_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('catering_services_no_results_page_content',array(
		'label'	=> __('Add Text','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'catering-services' ),
        ),
		'section'=> 'catering_services_no_results_page',
		'type'=> 'text'
	));

	//Social Icon Setting
	$wp_customize->add_section('catering_services_social_icon_settings',array(
		'title'	=> __('Social Icons Settings','catering-services'),
		'panel' => 'catering_services_other_parent_panel',
	));

	$wp_customize->add_setting('catering_services_social_icon_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_social_icon_font_size',array(
		'label'	=> __('Icon Font Size','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'catering-services' ),
        ),
		'section'=> 'catering_services_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_social_icon_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_social_icon_padding',array(
		'label'	=> __('Icon Padding','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'catering-services' ),
        ),
		'section'=> 'catering_services_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_social_icon_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_social_icon_width',array(
		'label'	=> __('Icon Width','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'catering-services' ),
        ),
		'section'=> 'catering_services_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('catering_services_social_icon_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('catering_services_social_icon_height',array(
		'label'	=> __('Icon Height','catering-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','catering-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'catering-services' ),
        ),
		'section'=> 'catering_services_social_icon_settings',
		'type'=> 'text'
	));


	//Responsive Media Settings
	$wp_customize->add_section('catering_services_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','catering-services'),
		'panel' => 'catering_services_other_parent_panel',
	));

    $wp_customize->add_setting( 'catering_services_resp_slider_hide_show',array(
      	'default' => 0,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'catering_services_switch_sanitization'
    ));
    $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','catering-services' ),
      	'section' => 'catering_services_responsive_media'
    )));

    $wp_customize->add_setting( 'catering_services_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
    ));
    $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','catering-services' ),
      	'section' => 'catering_services_responsive_media'
    )));

    $wp_customize->add_setting( 'catering_services_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
    ));
    $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','catering-services' ),
      	'section' => 'catering_services_responsive_media'
    )));

  //Woocommerce settings
	$wp_customize->add_section('catering_services_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'catering-services'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

	//Shop Page Featured Image
	$wp_customize->add_setting( 'catering_services_shop_featured_image_border_radius', array(
		'default'              => '0',
		'transport'        => 'refresh',
		'sanitize_callback'    => 'catering_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'catering_services_shop_featured_image_border_radius', array(
		'label'       => esc_html__( 'Shop Page Featured Image Border Radius','catering-services' ),
		'section'     => 'catering_services_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
		  'step'             => 1,
		  'min'              => 1,
		  'max'              => 50,
	),
	) );

	$wp_customize->add_setting( 'catering_services_shop_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'catering_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'catering_services_shop_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Shop Page Featured Image Box Shadow','catering-services' ),
		'section'     => 'catering_services_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'catering_services_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar',
		'render_callback' => 'catering_services_customize_partial_catering_services_woocommerce_shop_page_sidebar', ) );

  // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'catering_services_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new Catering_Services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','catering-services' ),
		'section' => 'catering_services_woocommerce_section'
  )));

  $wp_customize->add_setting('catering_services_shop_page_layout',array(
    'default' => 'Right Sidebar',
    'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control('catering_services_shop_page_layout',array(
    'type' => 'select',
    'label' => __('Shop Page Sidebar Layout','catering-services'),
    'section' => 'catering_services_woocommerce_section',
    'choices' => array(
        'Left Sidebar' => __('Left Sidebar','catering-services'),
        'Right Sidebar' => __('Right Sidebar','catering-services'),
        ),
	) );

  // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'catering_services_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar',
		'render_callback' => 'catering_services_customize_partial_catering_services_woocommerce_single_product_page_sidebar', ) );

	//Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'catering_services_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'catering_services_switch_sanitization'
	) );
	$wp_customize->add_control( new catering_services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','catering-services' ),
		'section' => 'catering_services_woocommerce_section'
	)));

 	$wp_customize->add_setting('catering_services_single_product_layout',array(
	    'default' => 'Right Sidebar',
	    'sanitize_callback' => 'catering_services_sanitize_choices'
	));
	$wp_customize->add_control('catering_services_single_product_layout',array(
	    'type' => 'select',
	    'label' => __('Single Product Sidebar Layout','catering-services'),
	    'section' => 'catering_services_woocommerce_section',
	    'choices' => array(
	        'Left Sidebar' => __('Left Sidebar','catering-services'),
	        'Right Sidebar' => __('Right Sidebar','catering-services'),
        ),
	) );

  //Products padding
  $wp_customize->add_setting('catering_services_products_padding_top_bottom',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('catering_services_products_padding_top_bottom',array(
    'label' => __('Products Padding Top Bottom','catering-services'),
    'description' => __('Enter a value in pixels. Example:20px','catering-services'),
    'input_attrs' => array(
      'placeholder' => __( '10px', 'catering-services' ),
    ),
    'section'=> 'catering_services_woocommerce_section',
    'type'=> 'text'
  ));

  $wp_customize->add_setting('catering_services_products_padding_left_right',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('catering_services_products_padding_left_right',array(
    'label' => __('Products Padding Left Right','catering-services'),
    'description' => __('Enter a value in pixels. Example:20px','catering-services'),
    'input_attrs' => array(
      'placeholder' => __( '10px', 'catering-services' ),
      ),
    'section'=> 'catering_services_woocommerce_section',
    'type'=> 'text'
  ));

  //Products box shadow
  $wp_customize->add_setting( 'catering_services_products_box_shadow', array(
    'default' => '',
    'transport' => 'refresh',
    'sanitize_callback' => 'catering_services_sanitize_number_range'
  ) );
  $wp_customize->add_control( 'catering_services_products_box_shadow', array(
    'label' => esc_html__( 'Products Box Shadow','catering-services' ),
    'section' => 'catering_services_woocommerce_section',
    'type'  => 'range',
    'input_attrs' => array(
      'step' => 1,
      'min'  => 1,
      'max'  => 50,
    ),
  ) );

  //Products border radius
    $wp_customize->add_setting( 'catering_services_products_border_radius', array(
    'default' => '0',
    'transport' => 'refresh',
    'sanitize_callback' => 'catering_services_sanitize_number_range'
  ) );
  $wp_customize->add_control( 'catering_services_products_border_radius', array(
    'label' => esc_html__( 'Products Border Radius','catering-services' ),
    'section' => 'catering_services_woocommerce_section',
    'type' => 'range',
    'input_attrs' => array(
      'step' => 1,
      'min'  => 1,
      'max'  => 50,
    ),
  ) );

  $wp_customize->add_setting('catering_services_products_btn_padding_top_bottom',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('catering_services_products_btn_padding_top_bottom',array(
    'label' => __('Products Button Padding Top Bottom','catering-services'),
    'description' => __('Enter a value in pixels. Example:20px','catering-services'),
    'input_attrs' => array(
    'placeholder' => __( '10px', 'catering-services' ),
        ),
    'section'=> 'catering_services_woocommerce_section',
    'type'=> 'text'
  ));

  $wp_customize->add_setting('catering_services_products_btn_padding_left_right',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('catering_services_products_btn_padding_left_right',array(
    'label' => __('Products Button Padding Left Right','catering-services'),
    'description' => __('Enter a value in pixels. Example:20px','catering-services'),
    'input_attrs' => array(
    'placeholder' => __( '10px', 'catering-services' ),
        ),
    'section'=> 'catering_services_woocommerce_section',
    'type'=> 'text'
  ));

  $wp_customize->add_setting( 'catering_services_products_button_border_radius', array(
    'default'              => '0',
    'transport'        => 'refresh',
    'sanitize_callback'    => 'catering_services_sanitize_number_range'
  ) );
  $wp_customize->add_control( 'catering_services_products_button_border_radius', array(
    'label'       => esc_html__( 'Products Button Border Radius','catering-services' ),
    'section'     => 'catering_services_woocommerce_section',
    'type'        => 'range',
    'input_attrs' => array(
      'step'             => 1,
      'min'              => 1,
      'max'              => 50,
    ),
  ) );

  //Products Sale Badge
  $wp_customize->add_setting('catering_services_woocommerce_sale_position',array(
        'default' => 'right',
        'sanitize_callback' => 'catering_services_sanitize_choices'
  ));
  $wp_customize->add_control('catering_services_woocommerce_sale_position',array(
      'type' => 'select',
      'label' => __('Sale Badge Position','catering-services'),
      'section' => 'catering_services_woocommerce_section',
      'choices' => array(
          'left' => __('Left','catering-services'),
          'right' => __('Right','catering-services'),
      ),
  ) );

  $wp_customize->add_setting('catering_services_woocommerce_sale_font_size',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('catering_services_woocommerce_sale_font_size',array(
    'label' => __('Sale Font Size','catering-services'),
    'description' => __('Enter a value in pixels. Example:20px','catering-services'),
    'input_attrs' => array(
      'placeholder' => __( '10px', 'catering-services' ),
        ),
    'section'=> 'catering_services_woocommerce_section',
    'type'=> 'text'
  ));

  $wp_customize->add_setting( 'catering_services_woocommerce_sale_border_radius', array(
    'default'              => '100',
    'transport'        => 'refresh',
    'sanitize_callback'    => 'catering_services_sanitize_number_range'
  ) );
  $wp_customize->add_control( 'catering_services_woocommerce_sale_border_radius', array(
    'label'       => esc_html__( 'Sale Border Radius','catering-services' ),
    'section'     => 'catering_services_woocommerce_section',
    'type'        => 'range',
    'input_attrs' => array(
      'step'             => 1,
      'min'              => 1,
      'max'              => 50,
    ),
  ) );

  // Related Product
  $wp_customize->add_setting( 'catering_services_related_product_show_hide',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'catering_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new catering_services_Toggle_Switch_Custom_Control( $wp_customize, 'catering_services_related_product_show_hide',array(
      'label' => esc_html__( 'Related product','catering-services' ),
      'section' => 'catering_services_woocommerce_section'
  )));
}

add_action( 'customize_register', 'catering_services_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Catering_Services_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Catering_Services_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Catering_Services_Customize_Section_Pro( $manager,'catering_services_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'CATERING SERVICES PRO', 'catering-services' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'catering-services' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/catering-services-wordpress-theme/'),
		) )	);

		// Register sections.
		$manager->add_section(new Catering_Services_Customize_Section_Pro($manager,'catering_services_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'catering-services' ),
			'pro_text' => esc_html__( 'DOCS', 'catering-services' ),
			'pro_url'  => esc_url('https://www.vwthemesdemo.com/docs/free-catering-services/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'catering-services-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'catering-services-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Catering_Services_Customize::get_instance();
